// Functions in http_getip.c

void CheckIPStart(PXCHAR pDstIP, USHORT iDstPort);
void CheckIPHandleConnectEvent();
void CheckIPHandleDataEvent();
void CheckIPHandleExtraTask();
void CheckIPHandleCloseEvent();
void CheckIPHandleResetEvent();
void CheckIPHandleTimerOut();
void CheckIPFromStoredDns();

void HttpGetIPInitialize();
BOOLEAN HttpGetIPRun();
void HttpGetIPHandleTimer();
void HttpGetIPStart(PXCHAR pDstIP, USHORT iDstPort);
void HttpGetIPStartAgain();

// Functions in v_task.c
void OnPage12End();
